import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy } from '@angular/core';
import * as i1 from '@smallstack/axios-api-client';
import { AxiosApiClient, CalendarApi } from '@smallstack/axios-api-client';
import { CalendarComponent } from '@smallstack/calendar-components';
import { SQBuilder, SearchByFieldMatcher } from '@smallstack/typesystem';
import { BaseWidgetComponent } from '@smallstack/widget-core';

class CalendarWidgetComponent extends BaseWidgetComponent {
    constructor(axiosApiClient) {
        super();
        this.axiosApiClient = axiosApiClient;
        this.calendarEntries = [];
        this.subscription.add(this.data$.subscribe((data) => this.loadEvents(data)));
    }
    async changedVisibleRange(event) {
        this.startDate = event.start;
        this.endDate = event.end;
        if (this.data.calendarIds)
            await this.loadEvents(this.data);
    }
    async loadEvents(data) {
        this.calendarEntries = await AxiosApiClient.loadAllPages((page) => this.axiosApiClient
            .get(CalendarApi)
            .getCalendarEntries({
            size: 1000,
            page,
            search: SQBuilder.asString([
                {
                    fieldname: "calendarId",
                    value: data?.calendarIds,
                    matcher: SearchByFieldMatcher.IN
                },
                {
                    fieldname: "start",
                    value: this.startDate,
                    matcher: SearchByFieldMatcher.GREATER_THAN_EQUALS
                },
                {
                    fieldname: "start",
                    value: this.endDate,
                    matcher: SearchByFieldMatcher.LESS_THAN
                }
            ], "and")
        })
            .then((res) => res.data));
        this.cdr.markForCheck();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: CalendarWidgetComponent, deps: [{ token: i1.AxiosApiClient }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: CalendarWidgetComponent, isStandalone: true, selector: "calendar-widget", usesInheritance: true, ngImport: i0, template: "<smallstack-calendar\n  [calendarEntries]=\"calendarEntries\"\n  [calendarStartTime]=\"data?.calendarStartTime\"\n  [calendarEndTime]=\"data?.calendarEndTime\"\n  [calendarView]=\"data.calendarView\"\n  (visibleRangeChange)=\"changedVisibleRange($event)\"\n  fxFlex.lt-md=\"100\"\n>\n</smallstack-calendar>\n", dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "component", type: CalendarComponent, selector: "smallstack-calendar", inputs: ["calendarEntries", "calendarView", "calendarStartTime", "calendarEndTime"], outputs: ["visibleRangeChange"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: CalendarWidgetComponent, decorators: [{
            type: Component,
            args: [{ changeDetection: ChangeDetectionStrategy.OnPush, selector: "calendar-widget", standalone: true, imports: [CommonModule, CalendarComponent], template: "<smallstack-calendar\n  [calendarEntries]=\"calendarEntries\"\n  [calendarStartTime]=\"data?.calendarStartTime\"\n  [calendarEndTime]=\"data?.calendarEndTime\"\n  [calendarView]=\"data.calendarView\"\n  (visibleRangeChange)=\"changedVisibleRange($event)\"\n  fxFlex.lt-md=\"100\"\n>\n</smallstack-calendar>\n" }]
        }], ctorParameters: function () { return [{ type: i1.AxiosApiClient }]; } });

export { CalendarWidgetComponent };
//# sourceMappingURL=smallstack-data-widgets-calendar-widget.component-78c4bece.mjs.map
