import { SocketDtoDirectionEnum, SocketDtoTypeEnum } from '@smallstack/axios-api-client';
import { AllWidgetTags } from '@smallstack/widget-core';

const HttpRequestBtnWidgetConfiguration = {
    templateName: "Http Button",
    icon: "commercial",
    templateDescription: "Eine Komponente, die es erlaubt, per Knopfdruck einen Http Request abzuschicken.",
    dataSchema: {
        type: "object",
        properties: {
            url: {
                type: "string",
                title: "URL",
                description: "Endpunkt des HTTP Aufrufs"
            },
            method: {
                type: "string",
                title: "Methode",
                description: "Definiert die HTTP Methode des Aufrufs",
                default: "GET",
                enum: ["GET", "POST", "PUT", "PATCH", "DELETE"]
            },
            headers: {
                type: "string",
                title: "Header Feld",
                "x-schema-form": {
                    widget: "monaco",
                    monacoLanguage: "json"
                }
            },
            body: {
                type: "string",
                title: "Body",
                "x-schema-form": {
                    widget: "monaco",
                    monacoLanguage: "json"
                }
            },
            sendContextAsBody: {
                type: "boolean",
                title: "Kontext als Body senden"
            },
            buttonText: {
                type: "string",
                default: "HTTP-Button",
                title: "Text auf dem Button"
            },
            buttonIcon: {
                type: "string",
                title: "Icon auf dem Button"
            },
            buttonColor: {
                type: "string",
                title: "Button Farbe",
                default: "primary",
                enum: ["primary", "secondary", "accent", "warn"]
            },
            buttonAppearance: {
                type: "string",
                title: "Aussehen des Buttons",
                default: "flat",
                enum: ["basic", "raised", "stroked", "flat"]
            },
            buttonTooltip: {
                type: "string",
                title: "Tooltip auf dem Button"
            },
            authorized: {
                type: "boolean",
                title: "Authentifizierung",
                description: "Soll der Aufruf mit Backoffice Anmeldedaten erfolgen? Dies ist nützlich, wenn Sie unsere API verwenden und der gewählte Endpunkt eine Anmeldung erfordert. Senden Sie niemals Ihre Anmeldedaten an fremde Server!"
            },
            sendTenantAndResellerHeader: {
                type: "boolean",
                title: "Tenant & Reseller Header",
                description: "Falls aktiv, dann werden x-tenant-id und x-reseller-id Header mitgesendet. Dies ist erforderlich, falls die Cloud API angesprochen wird!"
            },
            width: {
                type: "string",
                title: "Breite des Buttons (%, px)"
            },
            height: {
                type: "string",
                title: "Höhe des Buttons (%, px)"
            },
            errorText: {
                type: "string",
                title: "Fehlernachricht",
                description: "Wird bei einem Fehler angezeigt"
            },
            successText: {
                type: "string",
                title: "Erfolgsnachricht",
                description: "Wird bei Erfolg angezeigt"
            },
            handleResponseAsFileDownload: {
                type: "boolean",
                title: "Antwort ist ein Dateidownload"
            }
        }
    },
    tags: AllWidgetTags,
    sockets: [
        {
            direction: SocketDtoDirectionEnum.Out,
            name: "httpRequestDone",
            type: SocketDtoTypeEnum.Undefined
        }
    ]
};

export { HttpRequestBtnWidgetConfiguration };
//# sourceMappingURL=smallstack-data-widgets-configuration-7d9aa849.mjs.map
