import { SocketDtoDirectionEnum, SocketDtoTypeEnum } from '@smallstack/axios-api-client';
import { LIST_CONTAINER_PAGE_SIZE_OPTIONS } from '@smallstack/store-components';
import { WidgetTag } from '@smallstack/widget-core';

const DATA_SOURCE_STORE = "store";
const DATA_SOURCE_DATATYPE = "dataType";
const DATA_SOURCE_CONTEXT = "context";
const SocketNames = {
    openCreationDialog: "openCreationDialog"
};
const SOCKETS = [
    { direction: SocketDtoDirectionEnum.In, name: SocketNames.openCreationDialog, type: SocketDtoTypeEnum.Undefined }
];
var DataTableRenderTypes;
(function (DataTableRenderTypes) {
    DataTableRenderTypes["RAW"] = "raw";
    DataTableRenderTypes["I18N"] = "i18n";
    DataTableRenderTypes["ICON"] = "icon";
    DataTableRenderTypes["IMAGE"] = "image";
    DataTableRenderTypes["DATE"] = "date";
    DataTableRenderTypes["STORE_PROPERTY"] = "storeProperty";
    DataTableRenderTypes["QR_CODE"] = "qrCode";
    DataTableRenderTypes["DIALOG"] = "dialog";
    DataTableRenderTypes["LINK"] = "link";
    DataTableRenderTypes["BOOLEAN"] = "boolean";
    DataTableRenderTypes["MARKDOWN"] = "markdown";
    DataTableRenderTypes["GOOGLE_MAP"] = "googleMap";
})(DataTableRenderTypes || (DataTableRenderTypes = {}));
const Configuration = {
    templateName: "Daten Tabelle (alt)",
    icon: "gantt-chart",
    templateDescription: "Zeigt Daten in einer Tabelle an. Kann mit Editoren oder Detail Ansichten erweitert werden.",
    dataSchema: {
        type: "object",
        properties: {
            listProperties: {
                title: "Tabellenspalten",
                description: "Welche Eigenschaften sollen in der Tabelle angezeigt werden?",
                type: "array",
                items: {
                    type: "object",
                    properties: {
                        property: { type: "string", title: "Name der Eigenschaft" },
                        title: { type: "string", title: "Spaltenüberschrift" },
                        renderer: { type: "string", enum: Object.values(DataTableRenderTypes), title: "Anzeigeform" },
                        sortable: { type: "boolean", title: "Sortierbar" }
                    },
                    allOf: [
                        {
                            if: {
                                properties: {
                                    renderer: { const: "icon" }
                                }
                            },
                            then: {
                                properties: {
                                    defaultIcon: {
                                        title: "Default Icon",
                                        type: "string",
                                        default: "",
                                        "x-schema-form": {
                                            widget: "icon"
                                        }
                                    },
                                    valueIconPairArray: {
                                        type: "array",
                                        items: {
                                            type: "object",
                                            properties: {
                                                value: {
                                                    type: "string",
                                                    title: "Wert"
                                                },
                                                icon: {
                                                    type: "string",
                                                    title: "Icon",
                                                    "x-schema-form": {
                                                        widget: "icon"
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        },
                        {
                            if: {
                                properties: {
                                    renderer: { const: "date" }
                                }
                            },
                            then: {
                                properties: {
                                    rendererDateFormat: {
                                        type: "string",
                                        enum: ["short", "shortDate", "shortTime"],
                                        title: "Datumsformat"
                                    }
                                }
                            }
                        },
                        {
                            if: {
                                properties: {
                                    renderer: { const: "storeProperty" }
                                }
                            },
                            then: {
                                properties: {
                                    rendererStorePropertyStore: {
                                        type: "string",
                                        title: "Store",
                                        "x-schema-form": {
                                            widget: "stores"
                                        }
                                    },
                                    rendererStorePropertyProperty: {
                                        type: "string",
                                        title: "Anzeigeeigenschaft"
                                    }
                                }
                            }
                        },
                        {
                            if: {
                                properties: {
                                    renderer: { const: DataTableRenderTypes.GOOGLE_MAP }
                                }
                            },
                            then: {
                                properties: {
                                    googleMapsPreviewHeight: {
                                        type: "number",
                                        title: "Vorschau Höhe",
                                        default: 80
                                    },
                                    googleMapsPreviewWidth: {
                                        type: "number",
                                        title: "Vorschau Breite",
                                        default: 120
                                    }
                                }
                            }
                        },
                        {
                            if: {
                                properties: {
                                    renderer: { const: "qrCode" }
                                }
                            },
                            then: {
                                properties: {
                                    qrCodePrefix: {
                                        type: "string",
                                        title: "QR Code Prefix",
                                        description: "Kann zum Beispiel eine URL sein. Der angegebene Eigenschaftswert wird hinten angehängt."
                                    }
                                }
                            }
                        },
                        {
                            if: {
                                properties: {
                                    renderer: { const: "i18n" }
                                }
                            },
                            then: {
                                properties: {
                                    i18nPrefix: {
                                        type: "string",
                                        title: "Prefix",
                                        description: "Ein Prefix für den I18n Schlüssel"
                                    }
                                }
                            }
                        },
                        {
                            if: {
                                properties: {
                                    renderer: { const: "dialog" }
                                }
                            },
                            then: {
                                properties: {
                                    dialogWidth: {
                                        type: "string",
                                        title: "Dialog Breite in %, px oder vw",
                                        default: "600px"
                                    },
                                    dialogHeight: {
                                        type: "string",
                                        title: "Dialog Höhe in %, px oder vh",
                                        default: "600px"
                                    },
                                    dialogButtonIcon: {
                                        type: "string",
                                        title: "Icon auf dem Button",
                                        default: "search",
                                        "x-schema-form": {
                                            widget: "icon"
                                        }
                                    },
                                    dialogUrlSyncParameter: {
                                        type: "string",
                                        title: "Url Sync Parameter",
                                        description: "Synchronisiert geöffnete Dialoge über die Url"
                                    }
                                }
                            }
                        },
                        {
                            if: {
                                properties: {
                                    renderer: { const: "link" }
                                }
                            },
                            then: {
                                properties: {
                                    linkLabel: {
                                        type: "string",
                                        title: "Link Label",
                                        description: "Definierbarer Text für den Link."
                                    },
                                    openLinkInNewWindow: {
                                        type: "boolean",
                                        title: "Link in einem neuen Fenster öffnen?"
                                    }
                                }
                            }
                        }
                    ]
                }
            },
            showEditButton: {
                title: "Bearbeiten",
                description: "Soll ein Bearbeiten Button angezeigt werden in der Liste?",
                type: "boolean"
            },
            showDeleteButton: {
                title: "Löschen",
                description: "Soll ein Löschen Button angezeigt werden in der Liste?",
                type: "boolean"
            },
            setPageSize: {
                title: "Anzahl Einträge",
                description: "Wie viele Einträge sollen standardmäßig angezeigt werden?",
                type: "string",
                enum: LIST_CONTAINER_PAGE_SIZE_OPTIONS,
                default: "10"
            },
            autoSortProperty: {
                title: "Automatisch Sortieren",
                description: "Geben Sie eine Eigenschaft an, nach der automatisch sortiert werden soll. Verwenden Sie ein Minus für umgekehrte Sortierung. Beispiele: createdAt, -createdAt, name or -age",
                type: "string"
            },
            dataSource: {
                title: "Datenquelle",
                type: "string",
                enum: [DATA_SOURCE_STORE, DATA_SOURCE_DATATYPE, DATA_SOURCE_CONTEXT],
                description: "Mit der Datenquelle bestimmen Sie, woher die Daten in Ihrer Liste stammen. Sie können einen Store (unsere interne Datenquelle), einen Ihrer eigenen Datentypen oder eine Eigenschaft des aktuellen Contexts verwenden."
            }
        },
        allOf: [
            {
                if: {
                    properties: {
                        dataSource: { const: DATA_SOURCE_DATATYPE }
                    }
                },
                then: {
                    properties: {
                        dataType: {
                            title: "DataType",
                            type: "string",
                            "x-schema-form": {
                                widget: "storeselect",
                                store: "dataTypes",
                                property: "path"
                            }
                        }
                    }
                }
            },
            {
                if: {
                    properties: {
                        dataSource: { const: DATA_SOURCE_STORE }
                    }
                },
                then: {
                    properties: {
                        store: {
                            title: "Store",
                            type: "string",
                            "x-schema-form": {
                                widget: "stores"
                            }
                        },
                        storeSearch: {
                            title: "Store Search",
                            type: "object",
                            description: "Diese Store Search wird ausgeführt, sobald das Widget geladen wird. Kann leer gelassen werden, um kompletten Inhalt anzuzeigen. Unterstützt Variablen.",
                            "x-schema-form": {
                                widget: "searchquery"
                            }
                        }
                    }
                }
            },
            {
                if: {
                    properties: {
                        dataSource: { const: DATA_SOURCE_CONTEXT }
                    }
                },
                then: {
                    properties: {
                        contextProperty: {
                            title: "Kontext Eigenschaft",
                            type: "string",
                            description: "Die Eigenschaft im Kontext, welche ein Array sein muss und als Datenquelle dienen soll."
                        }
                    }
                }
            }
        ]
    },
    tags: [WidgetTag.CMS, WidgetTag.CBO, WidgetTag.APPLICATION, WidgetTag.DASHBOARD],
    sockets: SOCKETS,
    deprecated: true,
    deprecatedMessage: [{ value: "Bitte verwenden Sie das neue Daten Tabellen Widget" }],
    deprecatedActions: [
        {
            buttonTitle: [{ value: "Zu neuem Daten Tabellen Widget migrieren" }],
            migrationFn: async (oldData) => {
                oldData.allowMultiDelete = false;
                oldData.showCreateButton = oldData.showEditButton;
                if (oldData.dataSource === DATA_SOURCE_CONTEXT)
                    throw new Error("Leider können Datentabellen, welche auf einem Kontext basieren, derzeit nicht automatisch migriert werden. Bitte stellen Sie das alte Datentabellen Widget erst auf die Datenquelle 'store' um und versuchen Sie es dann erneut!");
                delete oldData.dataSource;
                if (oldData.dataType) {
                    oldData.typeName = oldData.dataType;
                    delete oldData.dataType;
                }
                if (oldData.store) {
                    oldData.typeName = oldData.store;
                    delete oldData.store;
                }
                return { newWidgetName: "DataTableV2", newWidgetData: oldData };
            }
        }
    ]
};

export { Configuration, DATA_SOURCE_CONTEXT, DATA_SOURCE_DATATYPE, DATA_SOURCE_STORE, DataTableRenderTypes, SOCKETS, SocketNames };
//# sourceMappingURL=smallstack-data-widgets-configuration-fb0a53c4.mjs.map
