import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy } from '@angular/core';
import { RxFor } from '@rx-angular/template/for';
import { RxLet } from '@rx-angular/template/let';
import { RxPush } from '@rx-angular/template/push';
import { JsonByPathPipe, ObjectArrayValuePipe } from '@smallstack/common-components';
import { I18nComponent } from '@smallstack/i18n-components';
import { filterNullish, getJsonByPath } from '@smallstack/utils';
import { BaseWidgetComponent } from '@smallstack/widget-core';
import { combineLatest, map } from 'rxjs';

class ContextTableWidgetComponent extends BaseWidgetComponent {
    constructor() {
        super(...arguments);
        this.tableHeaders$ = combineLatest([this.context$, this.data$]).pipe(filterNullish({ filterEmptyObjects: true }), map(([context, data]) => {
            return getJsonByPath(context, data.headersContextVariable);
        }));
        this.tableBodyPositions$ = combineLatest([this.context$, this.data$]).pipe(filterNullish({ filterEmptyObjects: true }), map(([context, data]) => {
            return getJsonByPath(context, data.bodyPositionsContextVariable);
        }));
        this.headerDisplayProperty$ = this.data$.pipe(map((data) => data.headerDisplayProperty || "value"));
        this.bodyDisplayProperty$ = this.data$.pipe(map((data) => data.bodyDisplayProperty || "value"));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: ContextTableWidgetComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: ContextTableWidgetComponent, isStandalone: true, selector: "smallstack-context-table", usesInheritance: true, ngImport: i0, template: "<ng-container *rxLet=\"headerDisplayProperty$; let headerDisplayProperty\">\n  <ng-container *rxLet=\"bodyDisplayProperty$; let bodyDisplayProperty\">\n    <table>\n      <thead>\n        <tr>\n          <th *rxFor=\"let tableHeader of tableHeaders$ | push; trackByIndex\"\n            ><smallstack-i18n [data]=\"tableHeader | jsonByPath: headerDisplayProperty\"></smallstack-i18n\n          ></th>\n        </tr>\n      </thead>\n      <tbody>\n        <tr *rxFor=\"let tablePosition of tableBodyPositions$ | push; let index = index; trackByIndex\">\n          <td *rxFor=\"let tableHeader of tableHeaders$ | push; trackByIndex\">\n            <smallstack-i18n\n              [data]=\"tablePosition.values | objectArrayValue: 'key':tableHeader.key:bodyDisplayProperty\"\n            ></smallstack-i18n>\n          </td>\n        </tr>\n      </tbody>\n    </table>\n  </ng-container>\n</ng-container>\n", styles: ["table{width:100%;border:1px solid silver;border-spacing:0px;border-collapse:collapse}td,th{text-align:left;border:1px solid silver;padding:8px}\n"], dependencies: [{ kind: "directive", type: RxLet, selector: "[rxLet]", inputs: ["rxLet", "rxLetStrategy", "rxLetComplete", "rxLetError", "rxLetSuspense", "rxLetContextTrigger", "rxLetCompleteTrigger", "rxLetErrorTrigger", "rxLetSuspenseTrigger", "rxLetNextTrigger", "rxLetRenderCallback", "rxLetParent", "rxLetPatchZone"], outputs: ["rendered"] }, { kind: "directive", type: RxFor, selector: "[rxFor][rxForOf]", inputs: ["rxForOf", "rxForTemplate", "rxForStrategy", "rxForParent", "rxForPatchZone", "rxForTrackBy", "rxForRenderCallback"] }, { kind: "pipe", type: RxPush, name: "push" }, { kind: "pipe", type: JsonByPathPipe, name: "jsonByPath" }, { kind: "pipe", type: ObjectArrayValuePipe, name: "objectArrayValue" }, { kind: "component", type: I18nComponent, selector: "smallstack-i18n", inputs: ["data", "showMissingKey", "replacers", "locale", "translationStore"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: ContextTableWidgetComponent, decorators: [{
            type: Component,
            args: [{ changeDetection: ChangeDetectionStrategy.OnPush, selector: "smallstack-context-table", standalone: true, imports: [RxLet, RxFor, RxPush, JsonByPathPipe, ObjectArrayValuePipe, I18nComponent], template: "<ng-container *rxLet=\"headerDisplayProperty$; let headerDisplayProperty\">\n  <ng-container *rxLet=\"bodyDisplayProperty$; let bodyDisplayProperty\">\n    <table>\n      <thead>\n        <tr>\n          <th *rxFor=\"let tableHeader of tableHeaders$ | push; trackByIndex\"\n            ><smallstack-i18n [data]=\"tableHeader | jsonByPath: headerDisplayProperty\"></smallstack-i18n\n          ></th>\n        </tr>\n      </thead>\n      <tbody>\n        <tr *rxFor=\"let tablePosition of tableBodyPositions$ | push; let index = index; trackByIndex\">\n          <td *rxFor=\"let tableHeader of tableHeaders$ | push; trackByIndex\">\n            <smallstack-i18n\n              [data]=\"tablePosition.values | objectArrayValue: 'key':tableHeader.key:bodyDisplayProperty\"\n            ></smallstack-i18n>\n          </td>\n        </tr>\n      </tbody>\n    </table>\n  </ng-container>\n</ng-container>\n", styles: ["table{width:100%;border:1px solid silver;border-spacing:0px;border-collapse:collapse}td,th{text-align:left;border:1px solid silver;padding:8px}\n"] }]
        }] });

export { ContextTableWidgetComponent };
//# sourceMappingURL=smallstack-data-widgets-context-table-widget.component-30c89694.mjs.map
