import { KeyValuePipe, JsonPipe } from '@angular/common';
import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy } from '@angular/core';
import { RxFor } from '@rx-angular/template/for';
import { RxPush } from '@rx-angular/template/push';
import * as i3 from '@smallstack/common-components';
import { I18nComponent } from '@smallstack/i18n-components';
import { filterNullish, asyncMap, getJsonByPath, convertDotNotationPathToJsonSchemaPath } from '@smallstack/utils';
import * as i1 from '@smallstack/widget-core';
import { BaseWidgetComponent, WidgetRendererComponent } from '@smallstack/widget-core';
import { map, switchMap } from 'rxjs';

class DefaultDetailsViewWidgetComponent extends BaseWidgetComponent {
    constructor(widgetRegistry, schemaService) {
        super();
        this.widgetRegistry = widgetRegistry;
        this.schemaService = schemaService;
        this.model$ = this.context$.pipe(filterNullish(), map((context) => context.model));
        this.fields$ = this.context$.pipe(filterNullish(), switchMap(async (context) => {
            if (context.model && context.schema) {
                const properties = Object.keys(context.model).filter((key) => !["id", "lastUpdatedAt", "createdAt"].includes(key));
                return (await asyncMap(properties, async (key) => {
                    let propSchema = getJsonByPath(context.schema, convertDotNotationPathToJsonSchemaPath(key));
                    if (!propSchema) {
                        console.error("No schema found for key: ", key, " in schema: ", context.schema);
                        return undefined;
                    }
                    propSchema = await this.schemaService.evalRefSchema(propSchema);
                    return {
                        label: propSchema?.title,
                        value: context.model[key],
                        widget: this.widgetRegistry.getViewWidgetBySchema(propSchema)?.name,
                        schema: propSchema
                    };
                })).filter((val) => val !== undefined);
            }
            console.log("no schema or no model given via context:", context);
            return undefined;
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: DefaultDetailsViewWidgetComponent, deps: [{ token: i1.WidgetRegistry }, { token: i3.FrontendSchemaService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: DefaultDetailsViewWidgetComponent, isStandalone: true, selector: "smallstack-default-details-view-widget", usesInheritance: true, ngImport: i0, template: "<div class=\"smallstack-grid gap-2\">\n  <div *rxFor=\"let field of fields$\" class=\"flex flex-col gap-1 p-1\">\n    <smallstack-i18n\n      class=\"font-bold whitespace-nowrap text-ellipsis overflow-hidden\"\n      [data]=\"field.label\"\n    ></smallstack-i18n>\n    <smallstack-widget-renderer\n      [widget]=\"{ name: field.widget }\"\n      [context]=\"{ model: field.value, schema: field.schema }\"\n    ></smallstack-widget-renderer>\n  </div>\n</div>\n", dependencies: [{ kind: "directive", type: RxFor, selector: "[rxFor][rxForOf]", inputs: ["rxForOf", "rxForTemplate", "rxForStrategy", "rxForParent", "rxForPatchZone", "rxForTrackBy", "rxForRenderCallback"] }, { kind: "component", type: I18nComponent, selector: "smallstack-i18n", inputs: ["data", "showMissingKey", "replacers", "locale", "translationStore"] }, { kind: "component", type: WidgetRendererComponent, selector: "smallstack-widget-renderer", inputs: ["widget", "additionalProviders", "context", "class"], outputs: ["widgetChange"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: DefaultDetailsViewWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: "smallstack-default-details-view-widget", standalone: true, imports: [RxFor, RxPush, KeyValuePipe, JsonPipe, I18nComponent, WidgetRendererComponent], changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"smallstack-grid gap-2\">\n  <div *rxFor=\"let field of fields$\" class=\"flex flex-col gap-1 p-1\">\n    <smallstack-i18n\n      class=\"font-bold whitespace-nowrap text-ellipsis overflow-hidden\"\n      [data]=\"field.label\"\n    ></smallstack-i18n>\n    <smallstack-widget-renderer\n      [widget]=\"{ name: field.widget }\"\n      [context]=\"{ model: field.value, schema: field.schema }\"\n    ></smallstack-widget-renderer>\n  </div>\n</div>\n" }]
        }], ctorParameters: function () { return [{ type: i1.WidgetRegistry }, { type: i3.FrontendSchemaService }]; } });

export { DefaultDetailsViewWidgetComponent };
//# sourceMappingURL=smallstack-data-widgets-default-details-view-widget.component-cd5bdc33.mjs.map
