import * as i6 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy } from '@angular/core';
import * as i1 from '@smallstack/axios-api-client';
import * as i3 from '@smallstack/common-components';
import { LoadingElementDirective } from '@smallstack/common-components';
import * as i2 from '@smallstack/i18n-components';
import { IconComponent } from '@smallstack/theme-components';
import { replaceVariables, isJsonString, getValueFromStringProvider } from '@smallstack/utils';
import { BaseWidgetComponent } from '@smallstack/widget-core';
import axios from 'axios';

class HttpRequestBtnWidgetComponent extends BaseWidgetComponent {
    constructor(tokenService, notificationService, urlResolverService, axiosApiClient) {
        super();
        this.tokenService = tokenService;
        this.notificationService = notificationService;
        this.urlResolverService = urlResolverService;
        this.axiosApiClient = axiosApiClient;
    }
    executeMethod() {
        return async () => {
            const method = this.data.method;
            const url = replaceVariables(this.data.url, {
                ...(await this.urlResolverService.getMap()),
                ...this.context
            });
            let body;
            const headers = isJsonString(this.data.headers) ? JSON.parse(this.data.headers) : {};
            if (this.data.authorized)
                headers["Authorization"] = `Bearer ${this.tokenService.getLoginToken()}`;
            if (this.data.sendTenantAndResellerHeader) {
                headers["x-tenant-id"] = await getValueFromStringProvider(this.axiosApiClient.apiClientConfiguration.tenantId);
                headers["x-reseller-id"] = await getValueFromStringProvider(this.axiosApiClient.apiClientConfiguration.resellerId);
            }
            if (this.data.sendContextAsBody)
                body = this.context;
            else if (isJsonString(this.data.body))
                body = JSON.parse(this.data.body);
            else
                body = this.data.body;
            await this.notificationService.handlePromise(axios
                .request({
                method,
                url,
                headers,
                data: body,
                responseType: this.data.handleResponseAsFileDownload ? "blob" : "json"
            })
                .then((response) => {
                if (this.data.handleResponseAsFileDownload) {
                    // create file link in browser's memory
                    const href = URL.createObjectURL(response.data);
                    // create "a" HTML element with href to file & click
                    const link = document.createElement("a");
                    link.href = href;
                    // filename in header? {content-disposition: attachment; filename="HM1 Daimlerstraße 11 70736 Fellbach.pdf"}
                    if (response?.headers && response?.headers["content-disposition"]) {
                        const fileName = response.headers["content-disposition"].split("filename=")[1];
                        if (fileName)
                            link.setAttribute("download", decodeURIComponent(fileName.replace(/"/g, "")));
                        else
                            link.setAttribute("download", "unnamed-file");
                    }
                    else
                        link.setAttribute("download", "unnamed-file");
                    document.body.appendChild(link);
                    link.click();
                    // clean up "a" element & remove ObjectURL
                    document.body.removeChild(link);
                    URL.revokeObjectURL(href);
                }
            }), {
                successMsg: this.data.successText,
                errorMsg: this.data.errorText
            });
            await this.sendSocketData("httpRequestDone");
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: HttpRequestBtnWidgetComponent, deps: [{ token: i3.TokenService }, { token: i2.NotificationService }, { token: i3.UrlResolverService }, { token: i1.AxiosApiClient }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: HttpRequestBtnWidgetComponent, isStandalone: true, selector: "http-request-btn-widget", usesInheritance: true, ngImport: i0, template: "<div [ngClass]=\"{ 'tooltip tooltip-primary': data.buttonTooltip }\" attr.data-tip=\"{{ data.buttonTooltip }}\">\n  <button\n    [loadingFn]=\"executeMethod()\"\n    data-test=\"http-btn\"\n    attr.data-testid=\"http-button-{{ data.buttonIcon || data.buttonText }}\"\n    [ngClass]=\"{\n      'btn-action': !data.buttonText || data.buttonText === '',\n      btn: data.buttonText?.length > 0,\n      'btn-outline': data.buttonAppearance === 'stroked',\n      'shadow-xl': data.buttonAppearance === 'raised'\n    }\"\n    class=\"btn-{{ data.buttonColor }} flex flex-row gap-1 justify-center place-items-center\"\n  >\n    <smallstack-icon *ngIf=\"data.buttonIcon\" [name]=\"data.buttonIcon\"></smallstack-icon>\n    <span>{{ data.buttonText }}</span>\n  </button>\n</div>\n", dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i6.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i6.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: LoadingElementDirective, selector: "[loadingFn]", inputs: ["loadingFn", "isLoading"], exportAs: ["loadingFn"] }, { kind: "component", type: IconComponent, selector: "smallstack-icon", inputs: ["theme", "size", "name", "alias", "action", "actionSize", "spinning", "actionSpinning", "color", "themeColor", "actionColor", "badge", "dynamic", "badgeColor"], outputs: ["iconError"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: HttpRequestBtnWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: "http-request-btn-widget", changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, imports: [CommonModule, LoadingElementDirective, IconComponent], template: "<div [ngClass]=\"{ 'tooltip tooltip-primary': data.buttonTooltip }\" attr.data-tip=\"{{ data.buttonTooltip }}\">\n  <button\n    [loadingFn]=\"executeMethod()\"\n    data-test=\"http-btn\"\n    attr.data-testid=\"http-button-{{ data.buttonIcon || data.buttonText }}\"\n    [ngClass]=\"{\n      'btn-action': !data.buttonText || data.buttonText === '',\n      btn: data.buttonText?.length > 0,\n      'btn-outline': data.buttonAppearance === 'stroked',\n      'shadow-xl': data.buttonAppearance === 'raised'\n    }\"\n    class=\"btn-{{ data.buttonColor }} flex flex-row gap-1 justify-center place-items-center\"\n  >\n    <smallstack-icon *ngIf=\"data.buttonIcon\" [name]=\"data.buttonIcon\"></smallstack-icon>\n    <span>{{ data.buttonText }}</span>\n  </button>\n</div>\n" }]
        }], ctorParameters: function () { return [{ type: i3.TokenService }, { type: i2.NotificationService }, { type: i3.UrlResolverService }, { type: i1.AxiosApiClient }]; } });

export { HttpRequestBtnWidgetComponent };
//# sourceMappingURL=smallstack-data-widgets-http-request-btn-widget.component-2f5795f3.mjs.map
