import * as i6 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy } from '@angular/core';
import * as i1 from '@smallstack/typesystem-client';
import { IconComponent } from '@smallstack/theme-components';
import { getSchemaPropertiesKeys } from '@smallstack/utils';
import { BaseWidgetComponent } from '@smallstack/widget-core';
import Fuse from 'fuse.js';
import { BehaviorSubject, combineLatest, debounce, interval, filter, switchMap, map } from 'rxjs';

class OfflineSearchWidgetComponent extends BaseWidgetComponent {
    #type;
    constructor(rxCollectionService, frontendTypeRegistry) {
        super();
        this.rxCollectionService = rxCollectionService;
        this.searchText$ = new BehaviorSubject(undefined);
        this.models$ = combineLatest([this.data$, this.searchText$.pipe(debounce(() => interval(800)))]).pipe(filter(([data, searchText]) => data?.typePath !== undefined && searchText !== undefined), switchMap(async ([data, searchText]) => {
            const collection = await this.rxCollectionService.getCollection(data.typePath);
            return [data, searchText, collection];
        }), filter(([data, searchText, collection]) => collection !== undefined), switchMap(([data, searchText, collection]) => {
            const options = {
                sort: data.sort
            };
            // if (searchText !== undefined)
            //   options.selector = this.convertTextToQuery(searchText, collection.rxCollection.schema.jsonSchema as any);
            return collection.rxCollection
                .find(options)
                .$.pipe(map((values) => [values, collection, searchText]));
        }), map(([values, collection, searchText]) => {
            if (searchText) {
                let allProperties = [];
                if (this.#type?.searchableFields instanceof Array && this.#type.searchableFields.length > 0)
                    allProperties = this.#type.searchableFields;
                else
                    allProperties = getSchemaPropertiesKeys(collection.rxCollection.schema.jsonSchema).map((key) => {
                        return { name: key, weight: 10 };
                    });
                const fuse = new Fuse(values.map((val) => val.toJSON()), {
                    keys: allProperties,
                    isCaseSensitive: false,
                    includeScore: true,
                    shouldSort: true
                });
                return fuse.search(searchText).map((s) => ({ ...s.item, score: s.score }));
            }
            return values.map((val) => val.toJSON());
        }));
        this.subscription.add(this.models$.subscribe((models) => {
            void this.sendSocketData("models", models);
        }));
        this.subscription.add(this.data$.subscribe(async (data) => {
            if (data?.typePath !== undefined)
                this.#type = await frontendTypeRegistry.getTypeByPath(data.typePath);
            if (data?.executeOnLoad === true)
                this.searchText$.next("");
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: OfflineSearchWidgetComponent, deps: [{ token: i1.RxCollectionService }, { token: i1.FrontendTypeRegistry }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: OfflineSearchWidgetComponent, isStandalone: true, selector: "smallstack-offline-search-widget", usesInheritance: true, ngImport: i0, template: "<div class=\"form-control m-2\">\n  <div class=\"input-group\">\n    <input\n      #input\n      type=\"text\"\n      placeholder=\"Suchen...\"\n      class=\"input input-bordered w-full shadow-sm\"\n      (keyup)=\"searchText$.next($any($event.target).value)\"\n      (focus)=\"sendSocketData('focused')\"\n    />\n    <button\n      *ngIf=\"searchText$.value\"\n      class=\"btn btn-square btn-outline shadow-sm\"\n      (click)=\"searchText$.next(undefined)\"\n    >\n      <smallstack-icon\n        name=\"trash\"\n        theme=\"fluency-systems-regular\"\n        themeColor=\"daisyTheme.primary.textColor\"\n        size=\"md\"\n      ></smallstack-icon>\n    </button>\n    <button class=\"btn btn-square btn-primary shadow-sm\" (click)=\"searchText$.next(input.value)\">\n      <smallstack-icon\n        name=\"search\"\n        theme=\"fluency-systems-regular\"\n        themeColor=\"daisyTheme.primary.textColor\"\n        size=\"md\"\n      ></smallstack-icon>\n    </button>\n  </div>\n</div>\n", dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i6.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: IconComponent, selector: "smallstack-icon", inputs: ["theme", "size", "name", "alias", "action", "actionSize", "spinning", "actionSpinning", "color", "themeColor", "actionColor", "badge", "dynamic", "badgeColor"], outputs: ["iconError"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: OfflineSearchWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: "smallstack-offline-search-widget", changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, imports: [CommonModule, IconComponent], template: "<div class=\"form-control m-2\">\n  <div class=\"input-group\">\n    <input\n      #input\n      type=\"text\"\n      placeholder=\"Suchen...\"\n      class=\"input input-bordered w-full shadow-sm\"\n      (keyup)=\"searchText$.next($any($event.target).value)\"\n      (focus)=\"sendSocketData('focused')\"\n    />\n    <button\n      *ngIf=\"searchText$.value\"\n      class=\"btn btn-square btn-outline shadow-sm\"\n      (click)=\"searchText$.next(undefined)\"\n    >\n      <smallstack-icon\n        name=\"trash\"\n        theme=\"fluency-systems-regular\"\n        themeColor=\"daisyTheme.primary.textColor\"\n        size=\"md\"\n      ></smallstack-icon>\n    </button>\n    <button class=\"btn btn-square btn-primary shadow-sm\" (click)=\"searchText$.next(input.value)\">\n      <smallstack-icon\n        name=\"search\"\n        theme=\"fluency-systems-regular\"\n        themeColor=\"daisyTheme.primary.textColor\"\n        size=\"md\"\n      ></smallstack-icon>\n    </button>\n  </div>\n</div>\n" }]
        }], ctorParameters: function () { return [{ type: i1.RxCollectionService }, { type: i1.FrontendTypeRegistry }]; } });

export { OfflineSearchWidgetComponent };
//# sourceMappingURL=smallstack-data-widgets-offline-search-widget.component-ba1165eb.mjs.map
