import { CdkVirtualScrollViewport } from "@angular/cdk/scrolling";
import { MatDialog } from "@angular/material/dialog";
import { ActivatedRoute } from "@angular/router";
import { WidgetDto } from "@smallstack/axios-api-client";
import { BreakpointService, FrontendSchemaService, FrontendSmallstackType, RouterUtilService } from "@smallstack/common-components";
import { NotificationService } from "@smallstack/i18n-components";
import { InlineTranslation } from "@smallstack/i18n-shared";
import { SmallstackTypeSchema } from "@smallstack/typesystem";
import { FrontendTypeRegistry, RxCollectionService } from "@smallstack/typesystem-client";
import { convertGeoPointToLatLng } from "@smallstack/utils";
import { BaseWidgetComponent, WidgetTag } from "@smallstack/widget-core";
import { BehaviorSubject, Observable } from "rxjs";
import * as i0 from "@angular/core";
export interface DataTableV3ListProperty {
    columnName: string;
    index: number;
    property: string;
    title?: string | InlineTranslation;
    sortable: boolean;
    sortingMode?: "asStrings" | "asNumbers" | "foreignLabel";
    filterable?: boolean;
    filterSchemaOverride?: any;
    width?: number;
    renderer: string;
    rendererDateFormat?: string;
    rendererStorePropertyProperty?: string;
    rendererStorePropertyStore?: string;
    qrCodePrefix?: string;
    dialogButtonIcon?: string;
    dialogWidth?: string;
    dialogHeight?: string;
    dialogComponent?: WidgetDto;
    dialogUrlSyncParameter?: string;
    linkLabel?: string;
    openLinkInNewWindow?: boolean;
    valueIconPairArray?: [{
        value: string;
        icon: string;
    }];
    defaultIcon?: string;
    mappingArray?: [{
        value: string;
        mappedValue: string;
    }];
    defaultValue?: string;
    i18nPrefix?: string;
    googleMapsPreviewHeight?: number;
    googleMapsPreviewWidth?: number;
    widget?: WidgetDto;
    widgetContextType?: "property" | "full";
    currency?: string;
}
export interface DataTableV3Configuration {
    listProperties: DataTableV3ListProperty[];
    typeName: string;
    type: FrontendSmallstackType;
    showEditButton: boolean;
    showDeleteButton: boolean;
    showCreateButton: boolean;
    allowMultiDelete: boolean;
    showCheckboxes: boolean;
    showExportButton: boolean;
    showFullTextSearch: boolean;
    tableHeight: string;
    initialSortProperty: string;
}
export declare class DataTableV3WidgetComponent extends BaseWidgetComponent<DataTableV3Configuration> {
    private matDialog;
    private notificationService;
    private routerUtilService;
    private frontendTypeRegistry;
    private breakPointService;
    private rxCollectionService;
    private schemaService;
    private activatedRoute;
    height: string;
    protected SEARCH_RESULT_SCORE_SORT: string;
    private collection$;
    protected listProperties$: Observable<DataTableV3ListProperty[]>;
    protected columns$: Observable<string[]>;
    protected userSorting$: BehaviorSubject<{
        propertyName: string;
        direction: "asc" | "desc";
    }>;
    protected defaultSorting$: Observable<{
        propertyName: string;
        direction: "asc" | "desc";
    }>;
    protected searchTextInput$: BehaviorSubject<string>;
    protected searchText$: Observable<string>;
    protected sorting$: Observable<{
        propertyName: string;
        direction: "asc" | "desc";
    }>;
    protected totalCount$: Observable<number>;
    protected filterSearch$: BehaviorSubject<any>;
    protected filterBarVisible$: BehaviorSubject<boolean>;
    protected tableData$: Observable<any[]>;
    protected smallstackType$: Observable<FrontendSmallstackType>;
    protected searchResult$: Observable<any[]>;
    protected hasSearchResults$: Observable<boolean>;
    protected showFullTextSearch$: Observable<boolean>;
    protected searchableFields$: Observable<string>;
    protected componentHeight$: Observable<number>;
    protected isLoading$: BehaviorSubject<boolean>;
    protected isEmpty$: Observable<boolean>;
    protected isMobile$: BehaviorSubject<boolean>;
    protected selectedIds: string[];
    protected filterSchema$: Observable<SmallstackTypeSchema>;
    protected showCheckboxes$: Observable<boolean>;
    viewPort: CdkVirtualScrollViewport;
    protected containerWidth$: BehaviorSubject<string>;
    convertGeoPointToLatLng: typeof convertGeoPointToLatLng;
    googleMapsOverlayOpened: boolean;
    errors: string[];
    mappingArray: {
        [columnName: string]: {
            [value: string]: string;
        };
    };
    WidgetTag: typeof WidgetTag;
    constructor(matDialog: MatDialog, notificationService: NotificationService, routerUtilService: RouterUtilService, frontendTypeRegistry: FrontendTypeRegistry, breakPointService: BreakpointService, rxCollectionService: RxCollectionService, schemaService: FrontendSchemaService, activatedRoute: ActivatedRoute);
    get headerOffset(): string;
    get footerOffset(): string;
    protected sort(propertyName: string, direction: "asc" | "desc"): Promise<void>;
    protected removeSort(): Promise<void>;
    protected toggleSort(propertyName: string, isSortable: boolean): Promise<void>;
    protected setInlineFilter(propertyName: string, element: any): void;
    qrCodeDialog(value: string, prefix?: string): void;
    openDialog(lp: DataTableV3ListProperty, model: {
        id: string;
        [key: string]: unknown;
    }): Promise<void>;
    openEditor(model?: any): () => Promise<void>;
    deleteData(elem: {
        id: string;
    }): () => Promise<void>;
    deleteManyData(ids: string[]): () => Promise<void>;
    protected exportData(selectedIds: string[]): () => Promise<void>;
    protected toggleAll(checkboxEvent: Event): Promise<void>;
    protected toggleEntry(id: string, checkboxEvent: Event): Promise<void>;
    /** callback fn for when a widget got set */
    protected setWidgetListProperty(propertyName: string, newWidget: WidgetDto): Promise<void>;
    protected reload(forceCompleteReload: boolean): () => Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataTableV3WidgetComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DataTableV3WidgetComponent, "smallstack-data-table-v3-widget", never, {}, {}, never, never, true, never>;
}
